@@ -17,16 +17,40 @@ OC.L10N.register(
     "{user} has archived the board {before}" : "{user} užarchyvavo lentą {before}",
     "You have unarchived the board {board}" : "Jūs išarchyvavote lentą {board}",
     "{user} has unarchived the board {before}" : "{user} išarchyvavo lentą {before}",
+    "You have created a new list {stack} on board {board}" : "Jūs lentoje {board} sukūrėte naują sąrašą {stack}",
+    "{user} has created a new list {stack} on board {board}" : "{user} lentoje {board} sukūrė naują sąrašą {stack}",
+    "You have renamed list {before} to {stack} on board {board}" : "Jūs lentoje {board} pervadinote sąrašą {before} į {stack}",
+    "{user} has renamed list {before} to {stack} on board {board}" : "{user} lentoje {board} pervadino sąrašą {before} į {stack}",
+    "You have deleted list {stack} on board {board}" : "Jūs lentoje {board} ištrynėte sąrašą {stack}",
+    "{user} has deleted list {stack} on board {board}" : "{user} lentoje {board} ištrynė sąrašą {stack}",
+    "You have created card {card} in list {stack} on board {board}" : "Jūs lentoje {board}, sąraše {stack} sukūrėte kortelę {card}",
+    "{user} has created card {card} in list {stack} on board {board}" : "{user} lentoje {board}, sąraše {stack} sukūrė kortelę {card}",
+    "You have deleted card {card} in list {stack} on board {board}" : "Jūs lentoje {board}, sąraše {stack} ištrynėte kortelę {card}",
+    "{user} has deleted card {card} in list {stack} on board {board}" : "{user} lentoje {board}, sąraše {stack} ištrynė kortelę {card} ",
     "You have renamed the card {before} to {card}" : "Jūs pervadinote kortelę {before} į {card}",
     "{user} has renamed the card {before} to {card}" : "{user} pervadino kortelę {before} į {card}",
+    "You have added a description to card {card} in list {stack} on board {board}" : "Jūs lentoje {board}, sąraše {stack} į kortelę {card} pridėjote aprašą",
+    "{user} has added a description to card {card} in list {stack} on board {board}" : "{user} lentoje {board}, sąraše {stack} į kortelę {card} pridėjo aprašą",
+    "You have updated the description of card {card} in list {stack} on board {board}" : "Jūs lentoje {board}, sąraše {stack} atnaujinote kortelės {card} aprašą",
+    "{user} has updated the description of the card {card} in list {stack} on board {board}" : "{user} lentoje {board}, sąraše {stack} atnaujino kortelės {card} aprašą",
+    "You have archived card {card} in list {stack} on board {board}" : "Jūs lentoje {board}, sąraše {stack} užarchyvavote kortelę {card}",
+    "{user} has archived card {card} in list {stack} on board {board}" : "{user} lentoje {board}, sąraše {stack} užarchyvavo kortelę {card}",
+    "You have unarchived card {card} in list {stack} on board {board}" : "Jūs lentoje {board}, sąraše {stack} išarchyvavote kortelę {card}",
+    "{user} has unarchived card {card} in list {stack} on board {board}" : "{user} lentoje {board}, sąraše {stack} išarchyvavo kortelę {card}",
     "You have removed the due date of card {card}" : "Jūs pašalinote galutinį kortelės {card} terminą",
     "{user} has removed the due date of card {card}" : "{user} pašalino galutinį kortelės {card} terminą",
     "You have set the due date of card {card} to {after}" : "Jūs nustatėte galutinį kortelės {card} terminą į {after}",
     "{user} has set the due date of card {card} to {after}" : "{user} nustatė galutinį kortelės {card} terminą į {after}",
     "You have updated the due date of card {card} to {after}" : "Jūs atnaujinote galutinį kortelės {card} terminą į {after}",
     "{user} has updated the due date of card {card} to {after}" : "{user} atnaujino galutinį kortelės {card} terminą į {after}",
+    "You have added the tag {label} to card {card} in list {stack} on board {board}" : "Jūs lentoje {board}, sąraše {stack} į kortelę {card} pridėjote žymę {label}",
+    "{user} has added the tag {label} to card {card} in list {stack} on board {board}" : "{user} lentoje {board}, sąraše {stack} į kortelę {card} pridėjo žymę {label}",
+    "You have removed the tag {label} from card {card} in list {stack} on board {board}" : "Jūs lentoje {board}, sąraše {stack} iš kortelės {card} pašalinote žymę {label}",
+    "{user} has removed the tag {label} from card {card} in list {stack} on board {board}" : "{user} lentoje {board}, sąraše {stack} iš kortelės {card} pašalino žymę {label}",
     "You have assigned {assigneduser} to card {card} on board {board}" : "Jūs lentoje {board} prie kortelės {card} priskyrėte {assigneduser}",
     "{user} has assigned {assigneduser} to card {card} on board {board}" : "{user} lentoje {board} prie kortelės {card} priskyrė {assigneduser}",
+    "You have moved the card {card} from list {stackBefore} to {stack}" : "Jūs perkėlėte kortelę {card} iš sąrašo {stackBefore} į sąrašą {stack}",
+    "{user} has moved the card {card} from list {stackBefore} to {stack}" : "{user} perkėlė kortelę {card} iš sąrašo {stackBefore} į sąrašą {stack}",
     "You have added the attachment {attachment} to card {card}" : "Jūs pridėjote priedą {attachment} į kortelę {card}",
     "{user} has added the attachment {attachment} to card {card}" : "{user} pridėjo priedą {attachment} į kortelę {card}",
     "You have updated the attachment {attachment} on card {card}" : "Jūs atnaujinote priedą {attachment} kortelėje {card}",
@@ -41,10 +65,11 @@ OC.L10N.register(
     "Deck" : "Darbai",
     "Changes in the <strong>Deck app</strong>" : "Pakeitimai <strong>Darbų programėlėje</strong>",
     "A <strong>comment</strong> was created on a card" : "Kortelėje buvo sukurtas <strong>komentaras</strong>",
+    "Upcoming cards" : "Artėjančios kortelės",
     "Personal" : "Asmeniniai",
     "The card \"%s\" on \"%s\" has been assigned to you by %s." : "Kortelę \"%s\" ties \"%s\" priskyrė jums %s.",
     "{user} has assigned the card \"%s\" on \"%s\" to you." : "{user} priskyrė jums kortelę \"%s\" ties \"%s\".",
-    "The card \"%s\" on \"%s\" has reached its due date." : "Kortelė \"%s\" ties \"%s\" pasiekė savo galutinį terminą.",
+    "The card \"%s\" on \"%s\" has reached its due date." : "Kortelė „%s“, esanti lentoje „%s“, pasiekė savo galutinį terminą.",
     "%s has mentioned you in a comment on \"%s\"." : "%s paminėjo jus komentare ties \"%s\".",
     "{user} has mentioned you in a comment on \"%s\"." : "{user} paminėjo jus komentare ties \"%s\".",
     "The board \"%s\" has been shared with you by %s." : "Lentą \"%s\" su jumis bendrina %s.",
@@ -105,6 +130,8 @@ OC.L10N.register(
     "Toggle compact mode" : "Perjungti kompaktišką veikseną",
     "Details" : "Išsamiau",
     "Loading board" : "Įkeliama lenta",
+    "No lists available" : "Nėra sąrašų",
+    "Create a new list to add cards to this board" : "Norėdami pridėti korteles į šią lentą, sukurkite naują sąrašą",
     "Board not found" : "Lenta nerasta",
     "Sharing" : "Bendrinimas",
     "Tags" : "Žymės",
@@ -114,6 +141,7 @@ OC.L10N.register(
     "Undo" : "Atšaukti",
     "Deleted cards" : "Ištrintos kortelės",
     "Share board with a user, group or circle …" : "Bendrinti lentą su naudotoju, grupe ar ratu…",
+    "No participants found" : "Nerasta jokių dalyvių",
     "Board owner" : "Lentos savininkas",
     "(Group)" : "(Grupė)",
     "(Circle)" : "(Ratas)",
@@ -121,9 +149,14 @@ OC.L10N.register(
     "Can share" : "Can share",
     "Can manage" : "Gali tvarkyti",
     "Delete" : "Ištrinti",
+    "Add a new list" : "Pridėti naują sąrašą",
+    "Archive all cards" : "Archyvuoti visas korteles",
     "Delete list" : "Ištrinti sąrašą",
     "Add card" : "Pridėti kortelę",
+    "Archive all cards in this list" : "Archyvuoti visas korteles šiame sąraše",
     "Add a new card" : "Pridėti naują kortelę",
+    "Card name" : "Kortelės pavadinimas",
+    "List deleted" : "Sąrašas ištrintas",
     "Edit" : "Taisyti",
     "Add a new tag" : "Pridėti naują žymę",
     "title and color value must be provided" : "privalo būti pateiktos pavadinimo ir spalvos reikšmės",
@@ -133,6 +166,11 @@ OC.L10N.register(
     "Add this attachment" : "Pridėti šį priedą",
     "Delete Attachment" : "Ištrinti priedą",
     "Restore Attachment" : "Atkurti priedą",
+    "Attachments" : "Priedai",
+    "Comments" : "Komentarai",
+    "Modified" : "Pakeistas",
+    "Created" : "Sukurta",
+    "No comments yet. Begin the discussion!" : "Kol kas komentarų nėra. Pradėkite diskusiją!",
     "Assign a tag to this card…" : "Priskirti šiai kortelei žymę…",
     "Assign to users" : "Priskirti naudotojams",
     "Assign to users/groups/circles" : "Priskirti naudotojams/grupėms/ratams",
@@ -140,6 +178,12 @@ OC.L10N.register(
     "Due date" : "Terminas",
     "Set a due date" : "Nustatyti galutinį terminą",
     "Remove due date" : "Pašalinti terminą",
+    "Select Date" : "Pasirinkti datą",
+    "Save" : "Įrašyti",
+    "The comment cannot be empty." : "Komentaras negali būti tuščias.",
+    "The comment cannot be longer than 1000 characters." : "Komentaras negali būti ilgesnis nei 1000 simbolių.",
+    "Reply" : "Atsakyti",
+    "Update" : "Atnaujinti",
     "Description" : "Aprašas",
     "(Unsaved)" : "(Neįrašyta)",
     "(Saving…)" : "(Įrašoma…)",
@@ -147,36 +191,25 @@ OC.L10N.register(
     "Edit description" : "Taisyti aprašą",
     "View description" : "Rodyti aprašą",
     "Add Attachment" : "Pridėti priedą",
-    "Attachments" : "Priedai",
-    "Comments" : "Komentarai",
     "Choose attachment" : "Pasirinkite priedą",
-    "Select Date" : "Pasirinkti datą",
-    "Modified" : "Pakeistas",
-    "Created" : "Sukurta",
-    "No comments yet. Begin the discussion!" : "Kol kas komentarų nėra. Pradėkite diskusiją!",
-    "Save" : "Įrašyti",
-    "The comment cannot be empty." : "Komentaras negali būti tuščias.",
-    "The comment cannot be longer than 1000 characters." : "Komentaras negali būti ilgesnis nei 1000 simbolių.",
-    "Reply" : "Atsakyti",
-    "Update" : "Atnaujinti",
     "(group)" : "(grupė)",
     "(circle)" : "(ratas)",
     "Assign to me" : "Priskirti sau",
+    "Move card" : "Perkelti kortelę",
     "Unarchive card" : "Išarchyvuoti kortelę",
     "Archive card" : "Archyvuoti kortelę",
     "Delete card" : "Ištrinti kortelę",
-    "Move card" : "Perkelti kortelę",
     "Move card to another board" : "Perkelti kortelę į kitą lentą",
+    "Select a list" : "Pasirinkite sąrašą",
+    "Card deleted" : "Kortelė ištrinta",
     "seconds ago" : "prieš keletą sekundžių",
     "All boards" : "Visos lentos",
     "Archived boards" : "Archyvuotos lentos",
     "Shared with you" : "Bendrinama su jumis",
-    "Edit board" : "Taisyti lentą",
-    "Clone board " : "Dubliuoti lentą ",
-    "Unarchive board " : "Išarchyvuoti lentą ",
-    "Archive board " : "Archyvuoti lentą ",
-    "Delete board " : "Ištrinti lentą ",
+    "Show boards in calendar/tasks" : "Rodyti darbus kalendoriuje/užduotyse",
+    "Board name" : "Lentos pavadinimas",
     "Board details" : "Išsamiau apie lentą",
+    "Edit board" : "Taisyti lentą",
     "Board {0} deleted" : "Lenta {0} ištrinta",
     "An error occurred" : "Įvyko klaida",
     "Are you sure you want to delete the board {title}? This will delete all the data of this board." : "Ar tikrai norite ištrinti lentą, pavadinimu {title}? Tai ištrins visus šios lentos duomenis.",
@@ -184,6 +217,7 @@ OC.L10N.register(
     "Today" : "Šiandien",
     "Tomorrow" : "Rytoj",
     "This week" : "Šią savaitę",
+    "No due" : "Be galutinio termino",
     "Link to a board" : "Susieti su lenta",
     "Link to a card" : "Susieti su kortele",
     "Something went wrong" : "Kažkas nutiko",
