@@ -51,8 +51,8 @@ OC.L10N.register(
     "{user} has assigned {assigneduser} to card {card} on board {board}" : "{user} dodeli nalogo {card} v zbirki {board} → {assigneduser}",
     "You have unassigned {assigneduser} from card {card} on board {board}" : "Odvzamete nalogo {card} v zbirki {board} ✕ {assigneduser}",
     "{user} has unassigned {assigneduser} from card {card} on board {board}" : "{user} odvzame nalogo {card} v zbirki {board} ✕ {assigneduser}",
-    "You have moved the card {card} from list {stackBefore} to {stack}" : "Premaknete nalogo {card} iz seznama nalog {stackBefore} v {stack}",
-    "{user} has moved the card {card} from list {stackBefore} to {stack}" : "{user} premakne nalogo {card} iz seznama nalog {stackBefore} v {stack}",
+    "You have moved the card {card} from list {stackBefore} to {stack}" : "Premaknete nalogo {card} s seznama nalog {stackBefore} v {stack}",
+    "{user} has moved the card {card} from list {stackBefore} to {stack}" : "{user} premakne nalogo {card} s seznama nalog {stackBefore} v {stack}",
     "You have added the attachment {attachment} to card {card}" : "Dodate prilogo {attachment} k nalogi {card}",
     "{user} has added the attachment {attachment} to card {card}" : "{user} doda prilogo {attachment} k nalogi {card}",
     "You have updated the attachment {attachment} on card {card}" : "Posodobite prilogo {attachment} v nalogi {card}",
@@ -63,17 +63,18 @@ OC.L10N.register(
     "{user} has restored the attachment {attachment} to card {card}" : "{user} obnovi prilogo {attachment} naloge {card}",
     "You have commented on card {card}" : "Vpišete opombo k nalogi {card}",
     "{user} has commented on card {card}" : "{user} vpiše opombo k nalogi {card}",
-    "A <strong>card description</strong> inside the Deck app has been changed" : "Spremenjen je<strong>opis ene izmed nalog</strong> v programu Deck",
+    "A <strong>card description</strong> inside the Deck app has been changed" : "V programu Deck je spremenjen <strong>opis ene izmed nalog</strong>",
     "Deck" : "Deck",
     "Changes in the <strong>Deck app</strong>" : "Spremembe v programu <strong>Deck</strong>",
     "A <strong>comment</strong> was created on a card" : "Nalogi je dodana nova <strong>opomba</strong>",
+    "Upcoming cards" : "Prihajajoče naloge",
     "Personal" : "Osebno",
     "The card \"%s\" on \"%s\" has been assigned to you by %s." : "Nalogo »%s« na »%s« vam dodeli %s.",
     "{user} has assigned the card \"%s\" on \"%s\" to you." : "{user} vam dodeli nalogo »%s« na »%s«.",
     "The card \"%s\" on \"%s\" has reached its due date." : "Naloga »%s« na »%s« je dosegla datum preteka.",
     "%s has mentioned you in a comment on \"%s\"." : "%s vas omeni v opombi na »%s«.",
     "{user} has mentioned you in a comment on \"%s\"." : "{user} vas omeni v opombi na »%s«.",
-    "The board \"%s\" has been shared with you by %s." : "Zborko »%s« vam dodeli %s.",
+    "The board \"%s\" has been shared with you by %s." : "Zbirko »%s« vam dodeli %s.",
     "{user} has shared the board %s with you." : "{user} vam omogoča souporabo zbirke %s.",
     "No data was provided to create an attachment." : "Ni podanih podatkov za ustvarjanje priloge.",
     "Finished" : "Končano",
@@ -134,6 +135,8 @@ OC.L10N.register(
     "Toggle compact mode" : "Preklopi način prikaza",
     "Details" : "Podrobnosti",
     "Loading board" : "Poteka nalaganje zbirke",
+    "No lists available" : "Ni razpoložljivih seznamov",
+    "Create a new list to add cards to this board" : "Ustvari nov seznam in doda kartice v zbirko",
     "Board not found" : "Zbirke ni mogoče najti",
     "Sharing" : "Souporaba",
     "Tags" : "Oznake",
@@ -143,6 +146,7 @@ OC.L10N.register(
     "Undo" : "Razveljavi",
     "Deleted cards" : "Izbrisane naloge",
     "Share board with a user, group or circle …" : "Souporaba z uporabniki, skupinami ali krogi ...",
+    "No participants found" : "Ni zaznanih udeleženev",
     "Board owner" : "Lastnik zbirke",
     "(Group)" : "(Skupina)",
     "(Circle)" : "(Krog)",
@@ -150,10 +154,15 @@ OC.L10N.register(
     "Can share" : "Lahko omogoči souporabo",
     "Can manage" : "Lahko upravlja",
     "Delete" : "Izbriši",
+    "Failed to create share with {displayName}" : "Souporaba z uporabnikom {displayName} je spodletela",
     "Add a new list" : "Dodaj nov seznam",
+    "Archive all cards" : "Arhiviraj vse kartice",
     "Delete list" : "Izbriši seznam",
     "Add card" : "Dodaj nalogo",
+    "Archive all cards in this list" : "Arhiviraj vse kartice tega seznama",
     "Add a new card" : "Dodaj novo nalogo",
+    "Card name" : "Ime kartice",
+    "List deleted" : "Seznam je izbrisan",
     "Edit" : "Uredi",
     "Add a new tag" : "Dodaj novo oznako",
     "title and color value must be provided" : "navedena morata biti podatka naslova in barve",
@@ -163,6 +172,14 @@ OC.L10N.register(
     "Add this attachment" : "Dodaj prilogo",
     "Delete Attachment" : "Izbriši prilogo",
     "Restore Attachment" : "Obnovi prilogo",
+    "Open in sidebar view" : "Odpri v bočnem pogledu",
+    "Open in bigger view" : "Odpri v povečanem pogledu",
+    "Attachments" : "Priloge",
+    "Comments" : "Opombe",
+    "Modified" : "Spremenjeno",
+    "Created" : "Ustvarjeno",
+    "The title cannot be empty." : "Polje naslova ne sme biti prazno.",
+    "No comments yet. Begin the discussion!" : "Ni še odzivov, bodite prvi!",
     "Assign a tag to this card…" : "Dodeli oznako nalogi ...",
     "Assign to users" : "Dodeli uporabnikom",
     "Assign to users/groups/circles" : "Dodeli uporabnikom/skupinam/krogom",
@@ -170,6 +187,13 @@ OC.L10N.register(
     "Due date" : "Datum preteka",
     "Set a due date" : "Nastavi datum preteka",
     "Remove due date" : "Odstrani datum preteka",
+    "Select Date" : "Izbor datuma",
+    "Save" : "Shrani",
+    "The comment cannot be empty." : "Polje opombe ne sme biti prazno.",
+    "The comment cannot be longer than 1000 characters." : "Opomba ne sme biti daljša od 1000 znakov.",
+    "In reply to" : "V odgovor",
+    "Reply" : "Odgovori",
+    "Update" : "Posodobi",
     "Description" : "Opis",
     "(Unsaved)" : "(neshranjeno)",
     "(Saving…)" : "(shranjevanje ...)",
@@ -177,48 +201,40 @@ OC.L10N.register(
     "Edit description" : "Uredi opis",
     "View description" : "Pokaži opis",
     "Add Attachment" : "Dodaj prilogo",
-    "Attachments" : "Priloge",
-    "Comments" : "Opombe",
     "Choose attachment" : "Izbor priloge",
-    "Select Date" : "Izbor datuma",
-    "Modified" : "Spremenjeno",
-    "Created" : "Ustvarjeno",
-    "No comments yet. Begin the discussion!" : "Ni še odzivov, bodite prvi!",
-    "Save" : "Shrani",
-    "The comment cannot be empty." : "Polje opombe ne sme biti prazno.",
-    "The comment cannot be longer than 1000 characters." : "Opomba ne sme biti daljša od 1000 znakov.",
-    "In reply to" : "V odgovor",
-    "Reply" : "Odgovori",
-    "Update" : "Posodobi",
     "(group)" : "(skupina)",
     "(circle)" : "(krog)",
     "Assign to me" : "Nalogo dodeli meni",
     "Unassign myself" : "Odstrani me z naloge",
+    "Move card" : "Premakni nalogo",
     "Unarchive card" : "Povrni nalogo",
     "Archive card" : "Arhiviraj nalogo",
     "Delete card" : "Izbriši nalogo",
-    "Move card" : "Premakni nalogo",
     "Move card to another board" : "Premakni nalogo v drugo zbirko",
     "Select a list" : "Izbor seznama",
+    "Card deleted" : "Naloga je izbrisana",
     "seconds ago" : "pred nekaj sekundami",
     "All boards" : "Vse zbirke",
     "Archived boards" : "Arhivirane zbirke",
     "Shared with you" : "V souporabi z vami",
+    "Use modal card view" : "Uporabi modalni pogled nalog",
+    "Show boards in calendar/tasks" : "Pokaži zbirke v koledarjem in med opravili",
     "Limit deck usage of groups" : "Omeji uporabo zbirk na skupine",
     "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "Omejevanje programa prepreči uporabnikom, ki niso del teh skupin, ustvarjanje novih zbirk. Uporabniki bodo še vedno lahko spreminjali zbirke, ki so jih dobili v souporabo.",
-    "Edit board" : "Uredi zbirko",
-    "Clone board " : "Kloniraj zbirko",
-    "Unarchive board " : "Povrni zbirko iz arhiva",
-    "Archive board " : "Arhiviraj zbirko",
-    "Delete board " : "Izbriši zbirko",
+    "Board name" : "Ime  zbirke",
     "Board details" : "Podrobnosti zbirke",
+    "Edit board" : "Uredi zbirko",
     "Board {0} deleted" : "Zbirka {0} je izbrisana",
     "An error occurred" : "Prišlo je do napake.",
     "Are you sure you want to delete the board {title}? This will delete all the data of this board." : "Ali ste prepričani, da želite izbrisati zbirko »{title}«? S tem boste izbrisali tudi vse podatke zbirke.",
     "Delete the board?" : "Ali želite izbrisati zbirko?",
+    "Loading filtered view" : "Poteka nalaganje filtriranega pogleda",
     "Today" : "Danes",
     "Tomorrow" : "Jutri",
     "This week" : "Ta teden",
+    "No due" : "Ni datuma preteka",
+    "No upcoming cards" : "Ni prihajajočih nalog",
+    "upcoming cards" : "prihajajoče naloge",
     "Link to a board" : "Povezava do zbirke",
     "Link to a card" : "Povezava do naloge",
     "Something went wrong" : "Prišlo je do napake ...",
