@@ -144,21 +144,26 @@ OC.L10N.register(
     "Timeline" : "Tidslinje",
     "Deleted lists" : "Borttagna listor",
     "Undo" : "Ångra",
-    "Deleted cards" : "Radera kort",
+    "Deleted cards" : "Ta bort kort",
     "Share board with a user, group or circle …" : "Dela en tavla med en användare, grupp eller cirkel ...",
+    "Searching for users, groups and circles …" : "Söker efter användare, grupper och cirklar …",
+    "No participants found" : "Inga deltagare hittades",
     "Board owner" : "Tavlans ägare",
     "(Group)" : "(Grupp)",
     "(Circle)" : "(Cirkel)",
     "Can edit" : "Kan redigera",
     "Can share" : "Kan dela",
     "Can manage" : "Kan hanter",
-    "Delete" : "Radera",
+    "Delete" : "Ta bort",
+    "Failed to create share with {displayName}" : "Kunde inte skapa delning med {displayName}",
     "Add a new list" : "Lägg till en ny lista",
     "Archive all cards" : "Arkivera alla kort",
-    "Delete list" : "Radera lista",
+    "Delete list" : "Ta bort lista",
     "Add card" : "Lägg till kort",
     "Archive all cards in this list" : "Arkivera alla kort i denna lista",
     "Add a new card" : "Lägg till ett nytt kort",
+    "Card name" : "Kortets namn",
+    "List deleted" : "Listan har raderats",
     "Edit" : "Redigera",
     "Add a new tag" : "Lägg till en ny tagg",
     "title and color value must be provided" : "titel och färg måste anges",
@@ -170,6 +175,12 @@ OC.L10N.register(
     "Restore Attachment" : "Återställ bilaga",
     "Open in sidebar view" : "Öppna i sidofältet",
     "Open in bigger view" : "Öppna i större vy",
+    "Attachments" : "Bilagor",
+    "Comments" : "Kommentarer",
+    "Modified" : "Ändrad",
+    "Created" : "Skapat",
+    "The title cannot be empty." : "Titeln får inte lämnas tom.",
+    "No comments yet. Begin the discussion!" : "Inga kommentarer än. Börja diskussionen!",
     "Assign a tag to this card…" : "Tilldela en tagg till det här kortet ...",
     "Assign to users" : "Tilldela till användare",
     "Assign to users/groups/circles" : "Tilldela till användare/grupper/cirklar",
@@ -177,6 +188,13 @@ OC.L10N.register(
     "Due date" : "Slutdatum",
     "Set a due date" : "Sätt ett slutdatum",
     "Remove due date" : "Ta bort slutdatum",
+    "Select Date" : "Välj datum",
+    "Save" : "Spara",
+    "The comment cannot be empty." : "Kommentaren kan inte vara tom.",
+    "The comment cannot be longer than 1000 characters." : "Kommentaren kan inte vara längre än 1000 tecken.",
+    "In reply to" : "Som svar på",
+    "Reply" : "Svara",
+    "Update" : "Uppdatera",
     "Description" : "Beskrivning",
     "(Unsaved)" : "(Inte sparad)",
     "(Saving…)" : "(Sparar…)",
@@ -184,46 +202,33 @@ OC.L10N.register(
     "Edit description" : "Ändra beskrivning",
     "View description" : "Visa beskrivning",
     "Add Attachment" : "Lägg till bilaga",
-    "Attachments" : "Bilagor",
-    "Comments" : "Kommentarer",
     "Choose attachment" : "Välj bilaga",
-    "Select Date" : "Välj datum",
-    "Modified" : "Ändrad",
-    "Created" : "Skapat",
-    "No comments yet. Begin the discussion!" : "Inga kommentarer än. Börja diskussionen!",
-    "Save" : "Spara",
-    "The comment cannot be empty." : "Kommentaren kan inte vara tom.",
-    "The comment cannot be longer than 1000 characters." : "Kommentaren kan inte vara längre än 1000 tecken.",
-    "In reply to" : "Som svar på",
-    "Reply" : "Svara",
-    "Update" : "Uppdatera",
     "(group)" : " (grupp)",
     "(circle)" : "(cirkel)",
     "Assign to me" : "Tilldela till mig",
     "Unassign myself" : "Ta bort från mig själv",
+    "Move card" : "Flytta kort",
     "Unarchive card" : "Avarkivera kort",
     "Archive card" : "Arkivera kort",
     "Delete card" : "Ta bort kort",
-    "Move card" : "Flytta kort",
     "Move card to another board" : "Flytta kort till en annan tavla",
     "Select a list" : "Välj en lista",
+    "Card deleted" : "Kortet har raderats",
     "seconds ago" : "sekunder sedan",
     "All boards" : "Alla tavlor",
     "Archived boards" : "Arkiverade tavlor",
     "Shared with you" : "Delad med dig",
     "Use modal card view" : "Använd modal kort-vy",
+    "Show boards in calendar/tasks" : "Visa tavlor i kalender / uppgifter",
     "Limit deck usage of groups" : "Begränsa användningen av grupper",
     "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "Begränsa Deck blockerar användare som inte ingår i dessa grupper från att skapa egna tavlor. Användare kan fortfarande arbeta med tavlor som har delats med dem.",
-    "Edit board" : "Ändra tavla",
-    "Clone board " : "Kopiera tavla",
-    "Unarchive board " : "Ta bort tavlan ur arkivet",
-    "Archive board " : "Arkivera tavla",
-    "Delete board " : "Radera tavla",
+    "Board name" : "Tavlans namn",
     "Board details" : "Taveldetaljer",
+    "Edit board" : "Ändra tavla",
     "Board {0} deleted" : "Tavla {0} raderad",
     "An error occurred" : "Ett fel uppstod",
     "Are you sure you want to delete the board {title}? This will delete all the data of this board." : "Är du säker på att du vill radera tavla {title}? Detta kommer att radera all information från denna tavla.",
-    "Delete the board?" : "Radera tavlan?",
+    "Delete the board?" : "Ta bort tavlan?",
     "Loading filtered view" : "Laddar filtrerad vy",
     "Today" : "Idag",
     "Tomorrow" : "Imorgon",
